<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <title>
        {{ app_config['web_page']['title']|e }}
    </title>
    {% include "_head_meta.html.j2" %}
    <script type="module" src="/static/health.js"></script>
</head>

<body>
    <main class="contained-content">
        <h1>{{ app_config['web_page']['title']|e }} Health</h1>
        {{ header | safe }}
        <div id="check_box_container"></div>
        <div class="file-list" id="health"></div>
        <div class="file-list" id="profile"></div>
    </main>
</body>

</html>
