<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="utf-8">
    <title>
        {{ app_config['web_page']['title']|e }}
    </title>
    {% include "_head_meta.html.j2" %}
</head>

<body>
    <main class="contained-content">
        <h1>{{ app_config['web_page']['title']|e }}</h1>
        {{ header | safe }}
        {{ about_content | safe }}
    </main>
</body>

</html>
